import pandas as pd
import joblib
import os
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.preprocessing import StandardScaler
import mysql.connector

model = joblib.load("dietitian_referral_model.pkl")
scaler = joblib.load("scaler.pkl")

# ✅ Database Configuration (Modify if needed)
DB_CONFIG = {
    "host": "localhost",
    "user": "root",
    "password": "Immortal10!!",  # Replace with your actual password
    "database": "hospital_db"
}

# ✅ Step 1: Connect to the MySQL Database and Load Data
try:
    conn = mysql.connector.connect(**DB_CONFIG)
    query = "SELECT * FROM feeding_dashboard_data;"
    df = pd.read_sql(query, conn)
    conn.close()
    print("\n🟢 Successfully loaded data from MySQL database.")

except Exception as e:
    print(f"\n❌ Database Connection Error: {e}")
    exit()

# ✅ Step 2: Define Features & Target
features = [
    "end_tidal_co2", "feed_vol", "feed_vol_adm", "fio2", "fio2_ratio",
    "insp_time", "oxygen_flow_rate", "peep", "pip", "resp_rate",
    "sip", "tidal_vol", "tidal_vol_actual", "tidal_vol_kg",
    "tidal_vol_spontaneous", "bmi"
]
target = "referral"

# ✅ Step 3: Drop rows where target is missing
df = df.dropna(subset=[target])

# ✅ Step 4: Handle Missing Values in Features
df[features] = df[features].apply(pd.to_numeric, errors='coerce')  # Convert to numeric
df.fillna(df.median(), inplace=True)  # Replace missing values with median

# ✅ Step 5: Extract Features (X) and Target (y)
X = df[features]
y = df[target].astype(int)  # Ensure target is integer

# ✅ Step 6: Scale Features for Better Model Performance
scaler = StandardScaler()
X_scaled = scaler.fit_transform(X)

# ✅ Step 7: Split Data into Training and Testing Sets
X_train, X_test, y_train, y_test = train_test_split(X_scaled, y, test_size=0.2, random_state=42)

# ✅ Step 8: Train Model
model = RandomForestClassifier(n_estimators=100, random_state=42, class_weight="balanced")
model.fit(X_train, y_train)

# ✅ Step 9: Save Model & Scaler
joblib.dump(model, "dietitian_referral_model.pkl")
joblib.dump(scaler, "scaler.pkl")

print("\n🚀 **Training complete! Model & scaler saved successfully.**")
